@@ -1,5 +1,5 @@
 /*-
- * Copyright (c) 2008, 2009, 2012, 2013, 2016, 2017  Peter Pentchev
+ * Copyright (c) 2008, 2009, 2012, 2013, 2016 - 2018  Peter Pentchev
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -185,7 +185,7 @@ usage(const bool error)
 void
 version(void)
 {
-	puts("confget 2.1.0");
+	puts("confget 2.1.1");
 }
 
 /***
@@ -337,7 +337,8 @@ init(const int argc, char * const * const argv)
 		{ "BASE", "2.1" },
 		{ NULL, NULL },
 	};
-	if (qsections + qfeature + qfeatures > 1) {
+	if (qsections + qfeature + qfeatures + lflag + Lflag +
+	    (margc > 0 && !(Lflag || qfeature)) > 1) {
 		errx(1, "Only a single query at a time, please!");
 	} else if (qfeatures) {
 		if (margc > 0)
